Crate migration_rocksdb

DB Migration module.

Structs

Batch
A batch of key-value pairs to be written into the database.
ChangeColumns
An even simpler migration which just changes the number of columns.
Config
Migration config.
Manager
Manages database migration.
Progress
Prints a dot every max ticks

Traits

Migration
A generalized migration from the given db to a destination db.
SimpleMigration
A simple migration over key-value pairs of a single column.