Struct Batch

pub struct Batch { /* private fields */ }
A batch of key-value pairs to be written into the database.

Implementations

Source

impl Batch

pub fn new(config: &Config, column: u32) -> Self

Make a new batch with the given config.

pub fn insert( &mut self, key: Vec<u8>, value: Vec<u8>, dest: &mut Database, ) -> Result<()>

Insert a value into the batch, committing if necessary.

pub fn commit(&mut self, dest: &mut Database) -> Result<()>

Commit all the items in the batch to the given database.