DB Migration module.
Structs
- Batch
- A batch of key-value pairs to be written into the database.
- Change
Columns - An even simpler migration which just changes the number of columns.
- Config
- Migration config.
- Manager
- Manages database migration.
- Progress
- Prints a dot every
maxticks
Traits
- Migration
- A generalized migration from the given db to a destination db.
- Simple
Migration - A simple migration over key-value pairs of a single column.